@@ -99,7 +99,7 @@ ggplot.train <- function(data = NULL, mapping = NULL, metric = data$metric[1], p
       if(p >= 2) {
         leg_name <- paramData$label[paramData$parameter == dnm[3]]
         out <- out + geom_point(aes_string(color = dnm[3], shape = dnm[3]))
-        out <- out + geom_line(aes_string(color = dnm[3], shape = dnm[3]))
+        out <- out + geom_line(aes_string(color = dnm[3]))
         out <- out + scale_colour_discrete(name = leg_name) +
           scale_shape_discrete(name = leg_name)
       } else out <- out + geom_point() + geom_line()
